@@ -106,6 +106,14 @@ sub spam {
 	my $self = shift;
 	return $self->{session}->spam($self->{name});
 }
+sub approve {
+	my $self = shift;
+	return $self->{session}->approve($self->{name});
+}
+sub ignore_reports {
+	my $self = shift;
+	return $self->{session}->ignore_reports($self->{name});
+}
 sub edit {
     	my ($self, $text) = @_;
 	my $cmtid = $self->{session}->edit($self->{name}, $text);
@@ -168,9 +176,15 @@ Wraps a posted comment.
 
 Returns a list ref of replies underneath this comment.
 
-=item reply(...)
+=item reply
 
-Syntactic sugar for C<Reddit::Client::submit_comment()>.
+=item remove
+
+=item spam
+
+=item approve
+
+=item ignore_reports
 
 =back
 
